@@ -13,16 +13,11 @@
 
 // Base class for "feed" nodes.
 class Feed : public RootItem {
-  Q_OBJECT
+    Q_OBJECT
 
   public:
-
     // Specifies the auto-download strategy for the feed.
-    enum class AutoUpdateType {
-      DontAutoUpdate = 0,
-      DefaultAutoUpdate = 1,
-      SpecificAutoUpdate = 2
-    };
+    enum class AutoUpdateType { DontAutoUpdate = 0, DefaultAutoUpdate = 1, SpecificAutoUpdate = 2 };
 
     // Specifies the actual "status" of the feed.
     // For example if it has new messages, error
@@ -44,6 +39,7 @@ class Feed : public RootItem {
 
     virtual QList<Message> undeletedMessages() const;
     virtual QString additionalTooltip() const;
+    virtual Qt::ItemFlags additionalFlags() const;
     virtual bool markAsReadUnread(ReadStatus status);
     virtual bool cleanMessages(bool clean_read_only);
     virtual int countOfAllMessages() const;
@@ -57,15 +53,12 @@ class Feed : public RootItem {
     void setCountOfAllMessages(int count_all_messages);
     void setCountOfUnreadMessages(int count_unread_messages);
 
-    int autoUpdateInitialInterval() const;
-    void setAutoUpdateInitialInterval(int auto_update_interval);
+    int autoUpdateInterval() const;
+    void setAutoUpdateInterval(int auto_update_interval);
 
     AutoUpdateType autoUpdateType() const;
     void setAutoUpdateType(AutoUpdateType auto_update_type);
 
-    int autoUpdateRemainingInterval() const;
-    void setAutoUpdateRemainingInterval(int auto_update_remaining_interval);
-
     Status status() const;
     QString statusString() const;
     void setStatus(Feed::Status status, const QString& status_text = {});
@@ -84,6 +77,9 @@ class Feed : public RootItem {
     void setMessageFilters(const QList<QPointer<MessageFilter>>& messageFilters);
     void removeMessageFilter(MessageFilter* filter);
 
+    QDateTime lastUpdated() const;
+    void setLastUpdated(const QDateTime& last_updated);
+
   public slots:
     virtual void updateCounts(bool including_total_count);
 
@@ -96,8 +92,8 @@ class Feed : public RootItem {
     Status m_status;
     QString m_statusString;
     AutoUpdateType m_autoUpdateType;
-    int m_autoUpdateInitialInterval{};
-    int m_autoUpdateRemainingInterval{};
+    int m_autoUpdateInterval{}; // In seconds.
+    QDateTime m_lastUpdated;
     bool m_isSwitchedOff;
     bool m_openArticlesDirectly;
     int m_totalCount{};
